@@ -8,12 +8,13 @@ This is a file to pull the help for all programs in bin. Each script must be
 
 2020-06-08  DG  Init, based on spHelp
 2020-08-17  DG  Added XMID and WAVEMID
+2020-10-18  DG  Added m4l
 """
 import subprocess as sub
 from pathlib import Path
-from bin import sjd, sp_version
+from bin import sjd, sp_version, m4l
 
-__version__ = '3.0.1'
+__version__ = '3.1.0'
 
 argparsed = ['ap_test.py', 'boss_sha1sum.py', 'ds9_live.py', 'epics_fetch.py',
              'get_dust.py', 'sloan_log.py']
@@ -31,13 +32,15 @@ print('{:=^80}'.format('sjd.py'))
 print(sjd.__doc__)
 print('{:=^80}'.format('sp_version.py'))
 print(sp_version.__doc__)
+print('{:=^80}'.format('m4l.py'))
+print(m4l.__doc__)
 
 # Because these files don't have a main syntax, we can't import them and print
 # __doc__, so we have to read them manually
-wavemid = open('wave_mid.py', 'r').read()
+wavemid = open(bin_dir / 'wave_mid.py', 'r').read()
 print('{:=^80}'.format('wave_mid.py'))
 print(wavemid.split('"""')[1])
-xmid = open('x_mid.py', 'r').read()
+
+xmid = open(bin_dir / 'x_mid.py', 'r').read()
 print('{:=^80}'.format('x_mid.py'))
 print(xmid.split('"""')[1])
-
